"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const face_api_js_1 = require("face-api.js");
// Hooks
const use_context_hook_1 = __importDefault(require("../VideoRecognitionContext/use-context-hook"));
// Utils
const utils_1 = require("../../utils");
function useFaceDetector(videoRef, canvasRef, { fps = 30, enabled = true, onRecognizeFace, faceMatcherThreshold = 0.4, } = {}) {
    const timer = (0, react_1.useRef)(null);
    const { hasFaceApiLoaded, labels } = (0, use_context_hook_1.default)();
    const initializeDetection = (0, react_1.useCallback)(() => {
        const { current: video } = videoRef || {};
        if (!video || !hasFaceApiLoaded) {
            return;
        }
        const videoSize = {
            width: video.clientWidth,
            height: video.clientHeight
        };
        timer.current = setInterval(() => __awaiter(this, void 0, void 0, function* () {
            const { current: canvas } = canvasRef;
            if (!video || !canvas) {
                return;
            }
            const detections = yield (0, face_api_js_1.detectAllFaces)(video, new face_api_js_1.TinyFaceDetectorOptions())
                .withFaceLandmarks()
                .withFaceDescriptors();
            const resizedDetections = (0, face_api_js_1.resizeResults)(detections, videoSize);
            (0, face_api_js_1.matchDimensions)(canvas, videoSize);
            utils_1.canvasUtils.clearCanvas(canvas);
            if (labels.length) {
                utils_1.faceApiUtils.drawFaceMatcherDetections(canvas, labels, resizedDetections, faceMatcherThreshold, onRecognizeFace);
            }
            face_api_js_1.draw.drawDetections(canvas, resizedDetections);
        }), 1000 / fps);
    }, [fps, hasFaceApiLoaded]);
    (0, react_1.useEffect)(() => {
        if (!enabled || timer.current) {
            return;
        }
        initializeDetection();
        return () => {
            if (timer.current) {
                clearTimeout(timer.current);
                timer.current = null;
            }
        };
    }, [enabled, initializeDetection]);
    return {
        hasFaceApiLoaded
    };
}
exports.default = useFaceDetector;
//# sourceMappingURL=index.js.map