"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
function useWebcam(videoRef, userMediaOptions) {
    const { enabled = true, video, audio } = userMediaOptions || {};
    const [initialized, setInitialized] = (0, react_1.useState)(false);
    const [error, setError] = (0, react_1.useState)(null);
    (0, react_1.useEffect)(() => {
        if (initialized || !enabled || (!video && !audio)) {
            return;
        }
        const enableMediaStream = () => __awaiter(this, void 0, void 0, function* () {
            if (navigator.mediaDevices.getUserMedia === null || !(videoRef === null || videoRef === void 0 ? void 0 : videoRef.current)) {
                return;
            }
            try {
                const stream = yield navigator.mediaDevices.getUserMedia(userMediaOptions);
                videoRef.current.srcObject = stream;
                videoRef.current.play();
                setError(null);
                setInitialized(true);
            }
            catch (error) {
                setInitialized(false);
                setError(error);
            }
        });
        enableMediaStream();
    }, [initialized, userMediaOptions]);
    const getSnapshot = () => {
        if (!videoRef.current) {
            return;
        }
        const canvas = document.createElement("canvas");
        canvas.width = videoRef.current.videoWidth;
        canvas.height = videoRef.current.videoHeight;
        const ctx = canvas.getContext("2d");
        ctx === null || ctx === void 0 ? void 0 : ctx.drawImage(videoRef.current, 0, 0, canvas.width, canvas.height);
        const imageSrc = canvas.toDataURL('image/jpeg');
        return imageSrc;
    };
    return {
        error,
        initialized,
        getSnapshot,
    };
}
exports.default = useWebcam;
//# sourceMappingURL=index.js.map