import React, { useEffect, useMemo, useState } from "react";
// Lib
import { loadImageLabels, loadModels } from "../../lib/face-api";
export const FaceApiContext = React.createContext({
    hasFaceApiLoaded: false,
    labels: [],
});
export default function VideoRecognitionContextProvider({ children, faceApiModelsPath, imageLabels = {} }) {
    const [hasModelsLoaded, setModelsLoaded] = useState(false);
    const [hasLabelsLoaded, setLabelsLoaded] = useState(false);
    const [labels, setLabels] = useState([]);
    useEffect(() => {
        loadModels(faceApiModelsPath).then(() => {
            setModelsLoaded(true);
        });
    }, []);
    useEffect(() => {
        if (!hasModelsLoaded) {
            return;
        }
        loadImageLabels(imageLabels).then(labels => {
            setLabels(labels);
            setLabelsLoaded(true);
        });
    }, [hasModelsLoaded]);
    const contextValues = useMemo(() => ({
        hasFaceApiLoaded: hasModelsLoaded || hasLabelsLoaded,
        labels,
    }), [hasModelsLoaded, hasLabelsLoaded, labels]);
    return (React.createElement(FaceApiContext.Provider, { value: contextValues }, children));
}
//# sourceMappingURL=Provider.js.map