var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { useCallback, useEffect, useRef } from "react";
import { TinyFaceDetectorOptions, detectAllFaces, draw, matchDimensions, resizeResults } from "face-api.js";
// Hooks
import useFaceApiContext from "../VideoRecognitionContext/use-context-hook";
// Utils
import { canvasUtils, faceApiUtils } from "../../utils";
export default function useFaceDetector(videoRef, canvasRef, { fps = 30, enabled = true, onRecognizeFace, faceMatcherThreshold = 0.4, } = {}) {
    const timer = useRef(null);
    const { hasFaceApiLoaded, labels } = useFaceApiContext();
    const initializeDetection = useCallback(() => {
        const { current: video } = videoRef || {};
        if (!video || !hasFaceApiLoaded) {
            return;
        }
        const videoSize = {
            width: video.clientWidth,
            height: video.clientHeight
        };
        timer.current = setInterval(() => __awaiter(this, void 0, void 0, function* () {
            const { current: canvas } = canvasRef;
            if (!video || !canvas) {
                return;
            }
            const detections = yield detectAllFaces(video, new TinyFaceDetectorOptions())
                .withFaceLandmarks()
                .withFaceDescriptors();
            const resizedDetections = resizeResults(detections, videoSize);
            matchDimensions(canvas, videoSize);
            canvasUtils.clearCanvas(canvas);
            if (labels.length) {
                faceApiUtils.drawFaceMatcherDetections(canvas, labels, resizedDetections, faceMatcherThreshold, onRecognizeFace);
            }
            draw.drawDetections(canvas, resizedDetections);
        }), 1000 / fps);
    }, [fps, hasFaceApiLoaded]);
    useEffect(() => {
        if (!enabled || timer.current) {
            return;
        }
        initializeDetection();
        return () => {
            if (timer.current) {
                clearTimeout(timer.current);
                timer.current = null;
            }
        };
    }, [enabled, initializeDetection]);
    return {
        hasFaceApiLoaded
    };
}
//# sourceMappingURL=index.js.map